error.h: Remove some unused errors.
[paraslash.git] / filter.h
index 456a50de3a79c942299ddea50f21fc2169fac9f4..09e45913aa1f116a68e85039a8059f93f13d6822 100644 (file)
--- a/filter.h
+++ b/filter.h
@@ -1,19 +1,7 @@
 /*
  * Copyright (C) 2005-2007 Andre Noll <maan@systemlinux.org>
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
 /** \file filter.h filter-related structures and exported symbols from filter_chain.c */
@@ -75,12 +63,12 @@ struct filter_chain {
         * pointer to variable containing the number of bytes loaded in the output buffer
         */
                size_t *out_loaded;
-       /** non-zero if this filter wont' produce any more output */
-       int eof;
-       /** pointer to the eof flag of the receiving application */
-       int *input_eof;
-       /** pointer to the eof flag of the writing application */
-       int *output_eof;
+       /** Non-zero if this filter wont' produce any more output. */
+       int error;
+       /** Pointer to the error variable of the receiving application. */
+       int *input_error;
+       /** Pointer to the eof flag of the writing application. */
+       int *output_error;
        /** the task associated with the filter chain */
        struct task task;
 };
@@ -301,7 +289,7 @@ void *(*parse_config)(int argc, char **argv);
 };
 
 
-static inline void write_int16_host_endian(char *buf, int16_t val)
+static inline void write_int16_host_endian(char *buf, int val)
 {
 #ifdef WORDS_BIGENDIAN
        *buf = val >> 8;